Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BuildConfigLister ¶
type BuildConfigLister interface {
// List lists all BuildConfigs in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.BuildConfig, err error)
// BuildConfigs returns an object that can list and get BuildConfigs.
BuildConfigs(namespace string) BuildConfigNamespaceLister
BuildConfigListerExpansion
}
BuildConfigLister helps list BuildConfigs. All objects returned here must be treated as read-only.
func NewBuildConfigLister ¶
func NewBuildConfigLister(indexer cache.Indexer) BuildConfigLister
NewBuildConfigLister returns a new BuildConfigLister.
type BuildConfigListerExpansion ¶
type BuildConfigListerExpansion interface{}
BuildConfigListerExpansion allows custom methods to be added to BuildConfigLister.
type BuildConfigNamespaceLister ¶
type BuildConfigNamespaceLister interface {
// List lists all BuildConfigs in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.BuildConfig, err error)
// Get retrieves the BuildConfig from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.BuildConfig, error)
BuildConfigNamespaceListerExpansion
}
BuildConfigNamespaceLister helps list and get BuildConfigs. All objects returned here must be treated as read-only.
type BuildConfigNamespaceListerExpansion ¶
type BuildConfigNamespaceListerExpansion interface{}
BuildConfigNamespaceListerExpansion allows custom methods to be added to BuildConfigNamespaceLister.
type BuildLister ¶
type BuildLister interface {
// List lists all Builds in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.Build, err error)
// Builds returns an object that can list and get Builds.
Builds(namespace string) BuildNamespaceLister
BuildListerExpansion
}
BuildLister helps list Builds. All objects returned here must be treated as read-only.
func NewBuildLister ¶
func NewBuildLister(indexer cache.Indexer) BuildLister
NewBuildLister returns a new BuildLister.
type BuildListerExpansion ¶
type BuildListerExpansion interface{}
BuildListerExpansion allows custom methods to be added to BuildLister.
type BuildNamespaceLister ¶
type BuildNamespaceLister interface {
// List lists all Builds in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.Build, err error)
// Get retrieves the Build from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.Build, error)
BuildNamespaceListerExpansion
}
BuildNamespaceLister helps list and get Builds. All objects returned here must be treated as read-only.
type BuildNamespaceListerExpansion ¶
type BuildNamespaceListerExpansion interface{}
BuildNamespaceListerExpansion allows custom methods to be added to BuildNamespaceLister.