Documentation
¶
Index ¶
- type ConsoleCLIDownloadLister
- type ConsoleCLIDownloadListerExpansion
- type ConsoleExternalLogLinkLister
- type ConsoleExternalLogLinkListerExpansion
- type ConsoleLinkLister
- type ConsoleLinkListerExpansion
- type ConsoleNotificationLister
- type ConsoleNotificationListerExpansion
- type ConsolePluginLister
- type ConsolePluginListerExpansion
- type ConsoleQuickStartLister
- type ConsoleQuickStartListerExpansion
- type ConsoleYAMLSampleLister
- type ConsoleYAMLSampleListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ConsoleCLIDownloadLister ¶
type ConsoleCLIDownloadLister interface {
// List lists all ConsoleCLIDownloads in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.ConsoleCLIDownload, err error)
// Get retrieves the ConsoleCLIDownload from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.ConsoleCLIDownload, error)
ConsoleCLIDownloadListerExpansion
}
ConsoleCLIDownloadLister helps list ConsoleCLIDownloads. All objects returned here must be treated as read-only.
func NewConsoleCLIDownloadLister ¶
func NewConsoleCLIDownloadLister(indexer cache.Indexer) ConsoleCLIDownloadLister
NewConsoleCLIDownloadLister returns a new ConsoleCLIDownloadLister.
type ConsoleCLIDownloadListerExpansion ¶
type ConsoleCLIDownloadListerExpansion interface{}
ConsoleCLIDownloadListerExpansion allows custom methods to be added to ConsoleCLIDownloadLister.
type ConsoleExternalLogLinkLister ¶
type ConsoleExternalLogLinkLister interface {
// List lists all ConsoleExternalLogLinks in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.ConsoleExternalLogLink, err error)
// Get retrieves the ConsoleExternalLogLink from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.ConsoleExternalLogLink, error)
ConsoleExternalLogLinkListerExpansion
}
ConsoleExternalLogLinkLister helps list ConsoleExternalLogLinks. All objects returned here must be treated as read-only.
func NewConsoleExternalLogLinkLister ¶
func NewConsoleExternalLogLinkLister(indexer cache.Indexer) ConsoleExternalLogLinkLister
NewConsoleExternalLogLinkLister returns a new ConsoleExternalLogLinkLister.
type ConsoleExternalLogLinkListerExpansion ¶
type ConsoleExternalLogLinkListerExpansion interface{}
ConsoleExternalLogLinkListerExpansion allows custom methods to be added to ConsoleExternalLogLinkLister.
type ConsoleLinkLister ¶
type ConsoleLinkLister interface {
// List lists all ConsoleLinks in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.ConsoleLink, err error)
// Get retrieves the ConsoleLink from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.ConsoleLink, error)
ConsoleLinkListerExpansion
}
ConsoleLinkLister helps list ConsoleLinks. All objects returned here must be treated as read-only.
func NewConsoleLinkLister ¶
func NewConsoleLinkLister(indexer cache.Indexer) ConsoleLinkLister
NewConsoleLinkLister returns a new ConsoleLinkLister.
type ConsoleLinkListerExpansion ¶
type ConsoleLinkListerExpansion interface{}
ConsoleLinkListerExpansion allows custom methods to be added to ConsoleLinkLister.
type ConsoleNotificationLister ¶
type ConsoleNotificationLister interface {
// List lists all ConsoleNotifications in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.ConsoleNotification, err error)
// Get retrieves the ConsoleNotification from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.ConsoleNotification, error)
ConsoleNotificationListerExpansion
}
ConsoleNotificationLister helps list ConsoleNotifications. All objects returned here must be treated as read-only.
func NewConsoleNotificationLister ¶
func NewConsoleNotificationLister(indexer cache.Indexer) ConsoleNotificationLister
NewConsoleNotificationLister returns a new ConsoleNotificationLister.
type ConsoleNotificationListerExpansion ¶
type ConsoleNotificationListerExpansion interface{}
ConsoleNotificationListerExpansion allows custom methods to be added to ConsoleNotificationLister.
type ConsolePluginLister ¶
type ConsolePluginLister interface {
// List lists all ConsolePlugins in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.ConsolePlugin, err error)
// Get retrieves the ConsolePlugin from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.ConsolePlugin, error)
ConsolePluginListerExpansion
}
ConsolePluginLister helps list ConsolePlugins. All objects returned here must be treated as read-only.
func NewConsolePluginLister ¶
func NewConsolePluginLister(indexer cache.Indexer) ConsolePluginLister
NewConsolePluginLister returns a new ConsolePluginLister.
type ConsolePluginListerExpansion ¶
type ConsolePluginListerExpansion interface{}
ConsolePluginListerExpansion allows custom methods to be added to ConsolePluginLister.
type ConsoleQuickStartLister ¶
type ConsoleQuickStartLister interface {
// List lists all ConsoleQuickStarts in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.ConsoleQuickStart, err error)
// Get retrieves the ConsoleQuickStart from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.ConsoleQuickStart, error)
ConsoleQuickStartListerExpansion
}
ConsoleQuickStartLister helps list ConsoleQuickStarts. All objects returned here must be treated as read-only.
func NewConsoleQuickStartLister ¶
func NewConsoleQuickStartLister(indexer cache.Indexer) ConsoleQuickStartLister
NewConsoleQuickStartLister returns a new ConsoleQuickStartLister.
type ConsoleQuickStartListerExpansion ¶
type ConsoleQuickStartListerExpansion interface{}
ConsoleQuickStartListerExpansion allows custom methods to be added to ConsoleQuickStartLister.
type ConsoleYAMLSampleLister ¶
type ConsoleYAMLSampleLister interface {
// List lists all ConsoleYAMLSamples in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.ConsoleYAMLSample, err error)
// Get retrieves the ConsoleYAMLSample from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.ConsoleYAMLSample, error)
ConsoleYAMLSampleListerExpansion
}
ConsoleYAMLSampleLister helps list ConsoleYAMLSamples. All objects returned here must be treated as read-only.
func NewConsoleYAMLSampleLister ¶
func NewConsoleYAMLSampleLister(indexer cache.Indexer) ConsoleYAMLSampleLister
NewConsoleYAMLSampleLister returns a new ConsoleYAMLSampleLister.
type ConsoleYAMLSampleListerExpansion ¶
type ConsoleYAMLSampleListerExpansion interface{}
ConsoleYAMLSampleListerExpansion allows custom methods to be added to ConsoleYAMLSampleLister.