Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type ImageExpansion
- type ImageInterface
- type ImageSignatureExpansion
- type ImageSignatureInterface
- type ImageSignaturesGetter
- type ImageStreamExpansion
- type ImageStreamImageExpansion
- type ImageStreamImageInterface
- type ImageStreamImagesGetter
- type ImageStreamImportExpansion
- type ImageStreamImportInterface
- type ImageStreamImportsGetter
- type ImageStreamInterface
- type ImageStreamMappingExpansion
- type ImageStreamMappingInterface
- type ImageStreamMappingsGetter
- type ImageStreamTagExpansion
- type ImageStreamTagInterface
- type ImageStreamTagsGetter
- type ImageStreamsGetter
- type ImageTagExpansion
- type ImageTagInterface
- type ImageTagsGetter
- type ImageV1Client
- func (c *ImageV1Client) ImageSignatures() ImageSignatureInterface
- func (c *ImageV1Client) ImageStreamImages(namespace string) ImageStreamImageInterface
- func (c *ImageV1Client) ImageStreamImports(namespace string) ImageStreamImportInterface
- func (c *ImageV1Client) ImageStreamMappings(namespace string) ImageStreamMappingInterface
- func (c *ImageV1Client) ImageStreamTags(namespace string) ImageStreamTagInterface
- func (c *ImageV1Client) ImageStreams(namespace string) ImageStreamInterface
- func (c *ImageV1Client) ImageTags(namespace string) ImageTagInterface
- func (c *ImageV1Client) Images() ImageInterface
- func (c *ImageV1Client) RESTClient() rest.Interface
- type ImageV1Interface
- type ImagesGetter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ImageExpansion ¶
type ImageExpansion interface{}
type ImageInterface ¶
type ImageInterface interface {
Create(ctx context.Context, image *v1.Image, opts metav1.CreateOptions) (*v1.Image, error)
Update(ctx context.Context, image *v1.Image, opts metav1.UpdateOptions) (*v1.Image, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.Image, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.ImageList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.Image, err error)
Apply(ctx context.Context, image *imagev1.ImageApplyConfiguration, opts metav1.ApplyOptions) (result *v1.Image, err error)
ImageExpansion
}
ImageInterface has methods to work with Image resources.
type ImageSignatureExpansion ¶
type ImageSignatureExpansion interface{}
type ImageSignatureInterface ¶
type ImageSignatureInterface interface {
Create(ctx context.Context, imageSignature *v1.ImageSignature, opts metav1.CreateOptions) (*v1.ImageSignature, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
ImageSignatureExpansion
}
ImageSignatureInterface has methods to work with ImageSignature resources.
type ImageSignaturesGetter ¶
type ImageSignaturesGetter interface {
ImageSignatures() ImageSignatureInterface
}
ImageSignaturesGetter has a method to return a ImageSignatureInterface. A group's client should implement this interface.
type ImageStreamExpansion ¶
type ImageStreamExpansion interface{}
type ImageStreamImageExpansion ¶
type ImageStreamImageExpansion interface{}
type ImageStreamImageInterface ¶
type ImageStreamImageInterface interface {
Get(ctx context.Context, name string, opts v1.GetOptions) (*imagev1.ImageStreamImage, error)
ImageStreamImageExpansion
}
ImageStreamImageInterface has methods to work with ImageStreamImage resources.
type ImageStreamImagesGetter ¶
type ImageStreamImagesGetter interface {
ImageStreamImages(namespace string) ImageStreamImageInterface
}
ImageStreamImagesGetter has a method to return a ImageStreamImageInterface. A group's client should implement this interface.
type ImageStreamImportExpansion ¶
type ImageStreamImportExpansion interface{}
type ImageStreamImportInterface ¶
type ImageStreamImportInterface interface {
Create(ctx context.Context, imageStreamImport *v1.ImageStreamImport, opts metav1.CreateOptions) (*v1.ImageStreamImport, error)
ImageStreamImportExpansion
}
ImageStreamImportInterface has methods to work with ImageStreamImport resources.
type ImageStreamImportsGetter ¶
type ImageStreamImportsGetter interface {
ImageStreamImports(namespace string) ImageStreamImportInterface
}
ImageStreamImportsGetter has a method to return a ImageStreamImportInterface. A group's client should implement this interface.
type ImageStreamInterface ¶
type ImageStreamInterface interface {
Create(ctx context.Context, imageStream *v1.ImageStream, opts metav1.CreateOptions) (*v1.ImageStream, error)
Update(ctx context.Context, imageStream *v1.ImageStream, opts metav1.UpdateOptions) (*v1.ImageStream, error)
UpdateStatus(ctx context.Context, imageStream *v1.ImageStream, opts metav1.UpdateOptions) (*v1.ImageStream, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.ImageStream, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.ImageStreamList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.ImageStream, err error)
Apply(ctx context.Context, imageStream *imagev1.ImageStreamApplyConfiguration, opts metav1.ApplyOptions) (result *v1.ImageStream, err error)
ApplyStatus(ctx context.Context, imageStream *imagev1.ImageStreamApplyConfiguration, opts metav1.ApplyOptions) (result *v1.ImageStream, err error)
Secrets(ctx context.Context, imageStreamName string, options metav1.GetOptions) (*v1.SecretList, error)
Layers(ctx context.Context, imageStreamName string, options metav1.GetOptions) (*v1.ImageStreamLayers, error)
ImageStreamExpansion
}
ImageStreamInterface has methods to work with ImageStream resources.
type ImageStreamMappingExpansion ¶
type ImageStreamMappingExpansion interface{}
type ImageStreamMappingInterface ¶
type ImageStreamMappingInterface interface {
Apply(ctx context.Context, imageStreamMapping *v1.ImageStreamMappingApplyConfiguration, opts metav1.ApplyOptions) (result *imagev1.ImageStreamMapping, err error)
Create(ctx context.Context, imageStreamMapping *imagev1.ImageStreamMapping, opts metav1.CreateOptions) (*metav1.Status, error)
ImageStreamMappingExpansion
}
ImageStreamMappingInterface has methods to work with ImageStreamMapping resources.
type ImageStreamMappingsGetter ¶
type ImageStreamMappingsGetter interface {
ImageStreamMappings(namespace string) ImageStreamMappingInterface
}
ImageStreamMappingsGetter has a method to return a ImageStreamMappingInterface. A group's client should implement this interface.
type ImageStreamTagExpansion ¶
type ImageStreamTagExpansion interface{}
type ImageStreamTagInterface ¶
type ImageStreamTagInterface interface {
Create(ctx context.Context, imageStreamTag *v1.ImageStreamTag, opts metav1.CreateOptions) (*v1.ImageStreamTag, error)
Update(ctx context.Context, imageStreamTag *v1.ImageStreamTag, opts metav1.UpdateOptions) (*v1.ImageStreamTag, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.ImageStreamTag, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.ImageStreamTagList, error)
ImageStreamTagExpansion
}
ImageStreamTagInterface has methods to work with ImageStreamTag resources.
type ImageStreamTagsGetter ¶
type ImageStreamTagsGetter interface {
ImageStreamTags(namespace string) ImageStreamTagInterface
}
ImageStreamTagsGetter has a method to return a ImageStreamTagInterface. A group's client should implement this interface.
type ImageStreamsGetter ¶
type ImageStreamsGetter interface {
ImageStreams(namespace string) ImageStreamInterface
}
ImageStreamsGetter has a method to return a ImageStreamInterface. A group's client should implement this interface.
type ImageTagExpansion ¶
type ImageTagExpansion interface{}
type ImageTagInterface ¶
type ImageTagInterface interface {
Create(ctx context.Context, imageTag *v1.ImageTag, opts metav1.CreateOptions) (*v1.ImageTag, error)
Update(ctx context.Context, imageTag *v1.ImageTag, opts metav1.UpdateOptions) (*v1.ImageTag, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.ImageTag, error)
List(ctx context.Context, opts metav1.ListOptions) (*v1.ImageTagList, error)
ImageTagExpansion
}
ImageTagInterface has methods to work with ImageTag resources.
type ImageTagsGetter ¶
type ImageTagsGetter interface {
ImageTags(namespace string) ImageTagInterface
}
ImageTagsGetter has a method to return a ImageTagInterface. A group's client should implement this interface.
type ImageV1Client ¶
type ImageV1Client struct {
// contains filtered or unexported fields
}
ImageV1Client is used to interact with features provided by the image.openshift.io group.
func New ¶
func New(c rest.Interface) *ImageV1Client
New creates a new ImageV1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*ImageV1Client, error)
NewForConfig creates a new ImageV1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new ImageV1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *ImageV1Client
NewForConfigOrDie creates a new ImageV1Client for the given config and panics if there is an error in the config.
func (*ImageV1Client) ImageSignatures ¶
func (c *ImageV1Client) ImageSignatures() ImageSignatureInterface
func (*ImageV1Client) ImageStreamImages ¶
func (c *ImageV1Client) ImageStreamImages(namespace string) ImageStreamImageInterface
func (*ImageV1Client) ImageStreamImports ¶
func (c *ImageV1Client) ImageStreamImports(namespace string) ImageStreamImportInterface
func (*ImageV1Client) ImageStreamMappings ¶
func (c *ImageV1Client) ImageStreamMappings(namespace string) ImageStreamMappingInterface
func (*ImageV1Client) ImageStreamTags ¶
func (c *ImageV1Client) ImageStreamTags(namespace string) ImageStreamTagInterface
func (*ImageV1Client) ImageStreams ¶
func (c *ImageV1Client) ImageStreams(namespace string) ImageStreamInterface
func (*ImageV1Client) ImageTags ¶
func (c *ImageV1Client) ImageTags(namespace string) ImageTagInterface
func (*ImageV1Client) Images ¶
func (c *ImageV1Client) Images() ImageInterface
func (*ImageV1Client) RESTClient ¶
func (c *ImageV1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type ImageV1Interface ¶
type ImageV1Interface interface {
RESTClient() rest.Interface
ImagesGetter
ImageSignaturesGetter
ImageStreamsGetter
ImageStreamImagesGetter
ImageStreamImportsGetter
ImageStreamMappingsGetter
ImageStreamTagsGetter
ImageTagsGetter
}
type ImagesGetter ¶
type ImagesGetter interface {
Images() ImageInterface
}
ImagesGetter has a method to return a ImageInterface. A group's client should implement this interface.